==> vtk-6.3.0-5-armv7h.pkg.tar.xz: vtk/vtkAxisFollower.java <==
// java wrapper for vtkAxisFollower object
//

package vtk;
import vtk.*;

public class vtkAxisFollower extends vtkFollower
{

  private native String GetClassName_0();
  public String GetClassName()
    { return GetClassName_0(); }

  private native int IsA_1(String id0);
  public int IsA(String id0)
    { return IsA_1(id0); }

  private native void SetAxis_2(vtkAxisActor id0);
  public void SetAxis(vtkAxisActor id0)
    { SetAxis_2(id0); }

  private native long GetAxis_3();
  public vtkAxisActor GetAxis() {
    long temp = GetAxis_3();

    if (temp == 0) return null;
    return (vtkAxisActor)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
  }

  private native void SetAutoCenter_4(int id0);
  public void SetAutoCenter(int id0)
    { SetAutoCenter_4(id0); }

  private native int GetAutoCenter_5();
  public int GetAutoCenter()
    { return GetAutoCenter_5(); }

  private native void AutoCenterOn_6();
  public void AutoCenterOn()
    { AutoCenterOn_6(); }

  private native void AutoCenterOff_7();
  public void AutoCenterOff()
    { AutoCenterOff_7(); }

  private native void SetEnableDistanceLOD_8(int id0);
  public void SetEnableDistanceLOD(int id0)
    { SetEnableDistanceLOD_8(id0); }

  private native int GetEnableDistanceLOD_9();
  public int GetEnableDistanceLOD()
    { return GetEnableDistanceLOD_9(); }

  private native void SetDistanceLODThreshold_10(double id0);
  public void SetDistanceLODThreshold(double id0)
    { SetDistanceLODThreshold_10(id0); }

  private native double GetDistanceLODThresholdMinValue_11();
  public double GetDistanceLODThresholdMinValue()
    { return GetDistanceLODThresholdMinValue_11(); }

  private native double GetDistanceLODThresholdMaxValue_12();
  public double GetDistanceLODThresholdMaxValue()
    { return GetDistanceLODThresholdMaxValue_12(); }

  private native double GetDistanceLODThreshold_13();
  public double GetDistanceLODThreshold()
    { return GetDistanceLODThreshold_13(); }

  private native void SetEnableViewAngleLOD_14(int id0);
  public void SetEnableViewAngleLOD(int id0)
    { SetEnableViewAngleLOD_14(id0); }

  private native int GetEnableViewAngleLOD_15();
  public int GetEnableViewAngleLOD()
    { return GetEnableViewAngleLOD_15(); }

  private native void SetViewAngleLODThreshold_16(double id0);
  public void SetViewAngleLODThreshold(double id0)
    { SetViewAngleLODThreshold_16(id0); }

  private native double GetViewAngleLODThresholdMinValue_17();
  public double GetViewAngleLODThresholdMinValue()
    { return GetViewAngleLODThresholdMinValue_17(); }

  private native double GetViewAngleLODThresholdMaxValue_18();
  public double GetViewAngleLODThresholdMaxValue()
    { return GetViewAngleLODThresholdMaxValue_18(); }

  private native double GetViewAngleLODThreshold_19();
  public double GetViewAngleLODThreshold()
    { return GetViewAngleLODThreshold_19(); }

  private native void SetScreenOffset_20(double id0);
  public void SetScreenOffset(double id0)
    { SetScreenOffset_20(id0); }

  private native double GetScreenOffset_21();
  public double GetScreenOffset()
    { return GetScreenOffset_21(); }

  private native int RenderOpaqueGeometry_22(vtkViewport id0);
  public int RenderOpaqueGeometry(vtkViewport id0)
    { return RenderOpaqueGeometry_22(id0); }

  private native int RenderTranslucentPolygonalGeometry_23(vtkViewport id0);
  public int RenderTranslucentPolygonalGeometry(vtkViewport id0)
    { return RenderTranslucentPolygonalGeometry_23(id0); }

  private native void Render_24(vtkRenderer id0);
  public void Render(vtkRenderer id0)
    { Render_24(id0); }

  private native void ComputeTransformMatrix_25(vtkRenderer id0);
  public void ComputeTransformMatrix(vtkRenderer id0)
    { ComputeTransformMatrix_25(id0); }

  private native void ShallowCopy_26(vtkProp id0);
  public void ShallowCopy(vtkProp id0)
    { ShallowCopy_26(id0); }

  private native double AutoScale_27(vtkViewport id0,vtkCamera id1,double id2,double id3[]);
  public double AutoScale(vtkViewport id0,vtkCamera id1,double id2,double id3[])
    { return AutoScale_27(id0,id1,id2,id3); }

  public vtkAxisFollower() { super(); }

  public vtkAxisFollower(long id) { super(id); }
  public native long   VTKInit();

}

==> vtk-7.1.1-4-armv7h.pkg.tar.xz: vtk/vtkAxisFollower.java <==
// java wrapper for vtkAxisFollower object
//

package vtk;
import vtk.*;

public class vtkAxisFollower extends vtkFollower
{

  private native String GetClassName_0();
  public String GetClassName()
    { return GetClassName_0(); }

  private native int IsA_1(String id0);
  public int IsA(String id0)
    { return IsA_1(id0); }

  private native void SetAxis_2(vtkAxisActor id0);
  public void SetAxis(vtkAxisActor id0)
    { SetAxis_2(id0); }

  private native long GetAxis_3();
  public vtkAxisActor GetAxis() {
    long temp = GetAxis_3();

    if (temp == 0) return null;
    return (vtkAxisActor)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native void SetAutoCenter_4(int id0);
  public void SetAutoCenter(int id0)
    { SetAutoCenter_4(id0); }

  private native int GetAutoCenter_5();
  public int GetAutoCenter()
    { return GetAutoCenter_5(); }

  private native void AutoCenterOn_6();
  public void AutoCenterOn()
    { AutoCenterOn_6(); }

  private native void AutoCenterOff_7();
  public void AutoCenterOff()
    { AutoCenterOff_7(); }

  private native void SetEnableDistanceLOD_8(int id0);
  public void SetEnableDistanceLOD(int id0)
    { SetEnableDistanceLOD_8(id0); }

  private native int GetEnableDistanceLOD_9();
  public int GetEnableDistanceLOD()
    { return GetEnableDistanceLOD_9(); }

  private native void SetDistanceLODThreshold_10(double id0);
  public void SetDistanceLODThreshold(double id0)
    { SetDistanceLODThreshold_10(id0); }

  private native double GetDistanceLODThresholdMinValue_11();
  public double GetDistanceLODThresholdMinValue()
    { return GetDistanceLODThresholdMinValue_11(); }

  private native double GetDistanceLODThresholdMaxValue_12();
  public double GetDistanceLODThresholdMaxValue()
    { return GetDistanceLODThresholdMaxValue_12(); }

  private native double GetDistanceLODThreshold_13();
  public double GetDistanceLODThreshold()
    { return GetDistanceLODThreshold_13(); }

  private native void SetEnableViewAngleLOD_14(int id0);
  public void SetEnableViewAngleLOD(int id0)
    { SetEnableViewAngleLOD_14(id0); }

  private native int GetEnableViewAngleLOD_15();
  public int GetEnableViewAngleLOD()
    { return GetEnableViewAngleLOD_15(); }

  private native void SetViewAngleLODThreshold_16(double id0);
  public void SetViewAngleLODThreshold(double id0)
    { SetViewAngleLODThreshold_16(id0); }

  private native double GetViewAngleLODThresholdMinValue_17();
  public double GetViewAngleLODThresholdMinValue()
    { return GetViewAngleLODThresholdMinValue_17(); }

  private native double GetViewAngleLODThresholdMaxValue_18();
  public double GetViewAngleLODThresholdMaxValue()
    { return GetViewAngleLODThresholdMaxValue_18(); }

  private native double GetViewAngleLODThreshold_19();
  public double GetViewAngleLODThreshold()
    { return GetViewAngleLODThreshold_19(); }

  private native double GetScreenOffset_20();
  public double GetScreenOffset()
    { return GetScreenOffset_20(); }

  private native void SetScreenOffset_21(double id0);
  public void SetScreenOffset(double id0)
    { SetScreenOffset_21(id0); }

  private native void SetScreenOffsetVector_22(double id0,double id1);
  public void SetScreenOffsetVector(double id0,double id1)
    { SetScreenOffsetVector_22(id0,id1); }

  private native void SetScreenOffsetVector_23(double id0[]);
  public void SetScreenOffsetVector(double id0[])
    { SetScreenOffsetVector_23(id0); }

  private native double[] GetScreenOffsetVector_24();
  public double[] GetScreenOffsetVector()
    { return GetScreenOffsetVector_24(); }

  private native int RenderOpaqueGeometry_25(vtkViewport id0);
  public int RenderOpaqueGeometry(vtkViewport id0)
    { return RenderOpaqueGeometry_25(id0); }

  private native int RenderTranslucentPolygonalGeometry_26(vtkViewport id0);
  public int RenderTranslucentPolygonalGeometry(vtkViewport id0)
    { return RenderTranslucentPolygonalGeometry_26(id0); }

  private native void Render_27(vtkRenderer id0);
  public void Render(vtkRenderer id0)
    { Render_27(id0); }

  private native void ComputeTransformMatrix_28(vtkRenderer id0);
  public void ComputeTransformMatrix(vtkRenderer id0)
    { ComputeTransformMatrix_28(id0); }

  private native void ShallowCopy_29(vtkProp id0);
  public void ShallowCopy(vtkProp id0)
    { ShallowCopy_29(id0); }

  private native double AutoScale_30(vtkViewport id0,vtkCamera id1,double id2,double id3[]);
  public double AutoScale(vtkViewport id0,vtkCamera id1,double id2,double id3[])
    { return AutoScale_30(id0,id1,id2,id3); }

  public vtkAxisFollower() { super(); }

  public vtkAxisFollower(long id) { super(id); }
  public native long   VTKInit();

}
